@@ -105,9 +105,7 @@ def render_gz(**payload):
             contents = contents.getvalue()
 
         with GzipFile(mode="wb", fileobj=gzip_buffer) as gzip_file:
-            gzip_file.write(
-                contents.encode("utf-8")
-            )  # need to give full contents to compression
+            gzip_file.write(contents)  # need to give full contents to compression
 
         body = gzip_buffer.getvalue()
         s3_client.put_object(
@@ -269,7 +267,7 @@ class ResourceView(MethodView):
 
                 dct = {"ids": primary_keys, "params": self._resource.params}
                 sha1 = hashlib.sha1(
-                    orjson.dumps(dct, option=orjson.OPT_SORT_KEYS).encode("utf-8")
+                    orjson.dumps(dct, option=orjson.OPT_SORT_KEYS, default=encode_default)
                 ).hexdigest()
                 key = f"{sha1}.{fmt}"
                 extra["s3"] = {"key": key, "update": False}
